addAxes: Add Axes or PBC Box to the 'rgl' Scene

addAxesR Documentation

Add Axes or PBC Box to the ‘rgl’ Scene

Description

Add lattice vectors, Cartesian axes or PBC box to the current ‘rgl’ scene.

Usage

addABC(x, lwd = 2, scale = NULL, labels = TRUE, cex = 2, adj.lab = 4, ...)

addXYZ(
  lwd = 2,
  scale = NULL,
  labels = TRUE,
  cex = 2,
  col = "black",
  alpha = NULL,
  ...,
  dx = 5,
  bidir = FALSE
)

addPBCBox(x, scale = NULL, lwd = 2, col = "black", alpha = 0.25)

addBBox(x, lwd = 2, col = "black", alpha = 0.25)

bbox.pdb(x)

Arguments

x

an object of class ‘crystal’ containing the unit cell parameters.

lwd

a numeric value indicating the line width used to draw the axes or the PBC box.

scale

a scalar value, or a numeric vector of length 2 or 3 or 6, or a 3x3 matrix used to scale the PBC box or the axes; a length 3 vector is converted to a diagonal matrix, while vectors of length 2 or 4 or 6 are converted to a diagonal matrix for scaling and a relative shift;

labels

a logical value indicating whether to draw the labels of the axes.

cex

a numeric value indicating the magnification used to draw the labels of the axes.

adj.lab

numeric value performing relative adjustment of label position;

...

further arguments passed to the rgl methods;

col

colour used for the PBC box;

alpha

a numeric value specifying the transparency of the lines;

dx

a numeric value specifying the absolute length of the xyz axes-vectors;

bidir

logical indicating to draw the XYZ-axes in both directions;

Details

addABC: Add the lattice vectors a, b and c to the current rgl device.
addXYZ: Add the Cartesian axes x, y and z to the current rgl device.
addPBCBox: Add a box representing the Periodic Boundary Conditions of a molecular system.
addBBox: Add a bounding box around the PDB molecule constructed using the lattice vectors.
bbox.pdb: Computes the bounding box around the PDB molecule.

Value

Returns invisibly a two-column data.frame containing the IDs and type indicators of the objects added to the scene.

bbox.pdb: Returns the coordinates of the bounding box.

See Also

visualize, rgl.open, par3d, addLabels

Examples

x <- read.pdb(system.file("examples/PCBM_ODCB.pdb", package="Rpdb"))
visualize(x, type = "l", xyz = FALSE, abc = FALSE, pbc.box = FALSE, mode = NULL)
addXYZ()
addABC(x)
addPBCBox(x)


Rpdb documentation built on May 12, 2026, 5:06 p.m.