chains: Extract Chain-Codes from a PDB Molecule Extract the codes of...

View source: R/chains.R

chainsR Documentation

Extract Chain-Codes from a PDB Molecule Extract the codes of all chains from a PDB object. chains is a generic function to extract the ids of the chains from a PDB molecule.

Description

Extract Chain-Codes from a PDB Molecule Extract the codes of all chains from a PDB object. chains is a generic function to extract the ids of the chains from a PDB molecule.

Usage

chains(x, ...)

## S3 method for class 'atoms'
chains(x, sorted = TRUE, ...)

## S3 method for class 'pdb'
chains(x, ...)

Arguments

x

Object of class pdb or class atoms;

...

arguments passed to other methods.

sorted

logical indicating if the returned chain-codes should be sorted;

Value

chains returns the codes of the individual chains in the molecule.


Rpdb documentation built on May 12, 2026, 5:06 p.m.