connect.nucleic: Connects atoms in Nucleic acids

View source: R/connect.NucleicAcids.R

connect.nucleicR Documentation

Connects atoms in Nucleic acids

Description

Builds the skeleton for a nucleic acid, by connecting the individual atoms for each nucleotide.

Usage

## S3 method for class 'nucleic'
connect(x, ...)

## S3 method for class 'pdb'
connect.nucleic(x, ...)

## S3 method for class 'atoms'
connect.nucleic(x, ...)

Arguments

x

a pdb of atoms object containing atomic identifiers.

...

arguments passed to methods.

Details

connect.nucleic is a generic function with methods for pdb and atoms objects. It creates object of class ‘connect’ with the skeleton of each nucleotide.

Value

connect.nucleic returns an object of class connect containing the explicit connections between all nucleotide atoms. Note: the detailed format of the returned value may change in the future.

See Also

pdb, connect

Examples

# Download some pdb files:
#   7EQJ = tRNA Val;
# x = read.pdb("9J4O.pdb")
# visualize(atoms(x), connect = connect.nucleic(x), type="l", pbc = FALSE);

Rpdb documentation built on May 12, 2026, 5:06 p.m.