format.pdb.title: Format "Title" Field of PDB File

View source: R/format.R

format.pdb.titleR Documentation

Format "Title" Field of PDB File

Description

Formats the title field of a Protein Data Bank (PDB) file.

Usage

## S3 method for class 'title'
format.pdb(x, ...)

## S3 method for class 'character'
format.pdb.title(x, ...)

Arguments

x

a vector of strings;

...

currently not used;

Details

This function is mostly used internally, e.g. by write.pdb, but may be useful in other instances as well.

Value

properly formatted text string.

See Also

write.pdb

Examples

format.pdb.title(c("Molecule 1", "is just an example"))

Rpdb documentation built on March 16, 2026, 5:07 p.m.