range.coords: Range of Atomic Coordinates

View source: R/range.coords.R

range.coordsR Documentation

Range of Atomic Coordinates

Description

Determines the range of atomic coordinates.

Usage

## S3 method for class 'coords'
range(x, na.rm = FALSE, finite = FALSE, ...)

## S3 method for class 'atoms'
range(x, na.rm = FALSE, finite = FALSE, ...)

## S3 method for class 'pdb'
range(x, na.rm = FALSE, finite = FALSE, ...)

lattice.range(x, xyz = NULL, ..., na.rm = TRUE)

## S3 method for class 'pdb'
lattice.range(x, xyz = NULL, ..., na.rm = TRUE)

## S3 method for class 'lattice'
range(x, ...)

## S3 method for class 'pdb'
range.lattice(x, xyz = NULL, ..., na.rm = TRUE)

Arguments

x

an R object containing atomic coordinates.

na.rm

logical, indicating if NA's should be omitted.

finite

logical, indicating if all non-finite elements should be omitted.

...

further arguments passed to or from other methods.

xyz

set of lattice vectors, by default extracted from the PDB object x.

Details

range computes the range of each of the coordinates. lattice.range computes the range of the relative coordinates when expressed in units of lattice vectors.

Value

Return a data.frame whose columns contain the range of the first, second and third coordinates of x.

See Also

range, coords, atoms, pdb

Examples

x <- read.pdb(system.file("examples/PCBM_ODCB.pdb", package="Rpdb"))
range(x)
range(range(x))


Rpdb documentation built on May 12, 2026, 5:06 p.m.