translate: Graphics Tools

View source: R/Graphics.Tools.R

translateR Documentation

Graphics Tools

Description

Tools to modify or set rgl objects, scenes and the observer. translate performs a translation of the observer to a new position specified using relative shifts. trans is an abbreviated alias to function translate.

Usage

trans(x, y = 0, z = 0, auto = FALSE)

translate(x, y = 0, z = 0, auto = FALSE)

Arguments

x, y, z

amount to shift the observer in the x, y and z directions.

auto

If TRUE, the location will be set automatically by RGL to make the whole bounding box visible. Unfortunately, it may fail, as it seems there are some bugs in rgl.

Value

translate returns invisibly the old position of the observer.


Rpdb documentation built on May 12, 2026, 5:06 p.m.