| chains | R Documentation |
chains is a generic function to extract the ids
of the chains from a PDB molecule.Extract Chain-Codes from a PDB Molecule
Extract the codes of all chains from a PDB object.
chains is a generic function to extract the ids
of the chains from a PDB molecule.
chains(x, ...)
## S3 method for class 'atoms'
chains(x, sorted = TRUE, ...)
## S3 method for class 'pdb'
chains(x, ...)
x |
Object of class |
... |
arguments passed to other methods. |
sorted |
logical indicating if the returned chain-codes should be sorted; |
chains returns the codes of the individual chains in the molecule.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.