View source: R/connect.NucleicAcids.R
| connect.nucleic | R Documentation |
Builds the skeleton for a nucleic acid, by connecting the individual atoms for each nucleotide.
## S3 method for class 'nucleic'
connect(x, ...)
## S3 method for class 'pdb'
connect.nucleic(x, ...)
## S3 method for class 'atoms'
connect.nucleic(x, ...)
x |
a |
... |
arguments passed to methods. |
connect.nucleic is a generic function with methods for
pdb and atoms objects.
It creates object of class ‘connect’ with the skeleton of each nucleotide.
connect.nucleic returns an object of class connect containing
the explicit connections between all nucleotide atoms.
Note: the detailed format of the returned value may change in the future.
pdb, connect
# Download some pdb files:
# 7EQJ = tRNA Val;
# x = read.pdb("9J4O.pdb")
# visualize(atoms(x), connect = connect.nucleic(x), type="l", pbc = FALSE);
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.