coords.atoms: The Atomic Coordinates of an Object of Class atoms
Description
Get or set the atomic coordinates of an object of class atoms.
Usage
## S3 method for class 'atoms':
coords(x, \dots)
## S3 method for class 'atoms':
coords(x) <- value
Arguments
x
an object of class atoms.
...
further arguments passed to or from other methods.
value
an object of class coords.
Value
The getter function return a data.frame of class coords whose columns contain the atomic coordinates of each element of a molecular system.
The coordinates can either be Cartesian or fractional coordinates depending on the basis attribute of x.
The setter function return a atoms object with updated atomic coordinates.
Details
The coords function extract the x1, x2 and x3 components of a atoms object
as well as its basis attribute to create a coords object.
The coords<- function set the x1, x2 and x3 components of a atoms object as well as its basis attribute.