| format.pdb.title | R Documentation |
Formats the title field of a Protein Data Bank (PDB) file.
## S3 method for class 'title'
format.pdb(x, ...)
## S3 method for class 'character'
format.pdb.title(x, ...)
x |
a vector of strings; |
... |
currently not used; |
This function is mostly used internally, e.g. by write.pdb,
but may be useful in other instances as well.
properly formatted text string.
write.pdb
format.pdb.title(c("Molecule 1", "is just an example"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.