xyz2abc: From Cartesian to Fractional Coordinates and Vice Versa

View source: R/xyz2abc.R

xyz2abcR Documentation

From Cartesian to Fractional Coordinates and Vice Versa

Description

Converts Cartesian coordinates into fractional coordinates and vice versa.

Usage

xyz2abc(...)

## S3 method for class 'coords'
xyz2abc(x, crystal, ..., cryst1 = NULL)

## S3 method for class 'atoms'
xyz2abc(x, crystal, ...)

## S3 method for class 'pdb'
xyz2abc(x, crystal = x$crystal, ..., cryst1 = NULL)

## S3 method for class 'distances'
xyz2abc(x, crystal, ...)

abc2xyz(...)

## S3 method for class 'coords'
abc2xyz(x, crystal, ..., cryst1 = NULL)

## S3 method for class 'atoms'
abc2xyz(x, crystal, ...)

## S3 method for class 'pdb'
abc2xyz(x, crystal = x$crystal, ..., cryst1 = NULL)

## S3 method for class 'distances'
abc2xyz(x, crystal, ...)

Arguments

...

arguments passed to methods.

x

an R object containing atomic coordinates.

crystal

an object of class crystal.

cryst1

will be deprecated; use crystal instead.

Details

For atoms and pdb objects, the atomic coordinates are first extracted from x using the coords function. Then, using the periodic boundary conditions stored into crystal, the coordinates are converted from Cartesian to fractional (for the xyz2abc functions) or from fractional to Cartesian (for the abc2xyz functions) coordinates. Finally, for atoms and pdb objects, the new atomic coordinates are reassigned to the original x object using the coords<- function and x is returned.

Value

Return an object of the same class as x, with atomic coordinates expressed in a different basis set.

See Also

basis, coords, atoms, pdb, crystal

Examples

x <- read.pdb(system.file("examples/PCBM_ODCB.pdb", package="Rpdb"))
basis(x)
x <- xyz2abc(x)
basis(x)
x <- abc2xyz(x)
basis(x)


  
  # This example returns an error because the coordinates stored
  # into the PDB file are already Cartesian coordinates.
  x <- read.pdb(system.file("examples/PCBM_ODCB.pdb", package="Rpdb"))
  try(x <- abc2xyz(x))



Rpdb documentation built on March 16, 2026, 5:07 p.m.